@@ -5,6 +5,7 @@ Examples of using the typed labels API
 
 import logging
 
+from examples.utils import pretty_print
 from kentik_api import DeviceLabel, KentikAPI
 from kentik_api.public.types import ID
 from kentik_api.utils import get_credentials
@@ -13,45 +14,30 @@ logging.basicConfig(level=logging.INFO)
 
 
 def run_crud() -> None:
-    """
-    Expected response is like:
-
-    ### CREATE
-    CreateResponse(id=2794, name='apitest-label-1', color='#0000FF', user_id='144319', company_id='74333', devices=[], created_date='2020-12-02T14:39:46.686Z', updated_date='2020-12-02T14:39:46.686Z')
-
-    ### UPDATE
-    UpdateResponse(id=2794, name='apitest-label-one', color='#FF0000', user_id='144319', company_id='74333', devices=[], created_date='2020-12-02T14:39:46.686Z', updated_date='2020-12-02T14:39:46.686Z')
-
-    ### GET
-    GetResponse(id=2794, name='apitest-label-one', color='#FF0000', user_id='144319', company_id='74333', devices=[], created_date='2020-12-02T14:39:46.686Z', updated_date='2020-12-02T14:39:46.686Z')
-
-    ### DELETE
-    DeleteResponse(success=True)
-    """
-
     email, token = get_credentials()
     client = KentikAPI(email, token)
 
     print("### CREATE")
     label = DeviceLabel.new("apitest-label-1", "#0000FF")
     created = client.device_labels.create(label)
-    print(created.__dict__)
+    pretty_print(created)
     print()
 
     print("### UPDATE")
     created.name = "apitest-label-one"
     updated = client.device_labels.update(created)
-    print(updated.__dict__)
+    pretty_print(updated)
     print()
 
     print("### GET")
     got = client.device_labels.get(updated.id)
-    print(got.__dict__)
+    pretty_print(got)
     print()
 
     print("### DELETE")
     deleted = client.device_labels.delete(updated.id)
     print(deleted)
+    print()
 
 
 def run_get_with_devices() -> None:
@@ -59,24 +45,25 @@ def run_get_with_devices() -> None:
     client = KentikAPI(email, token)
 
     print("### GET")
-    label_with_devices_id = ID(2752)
+    label_with_devices_id = ID("2752")
     got = client.device_labels.get(label_with_devices_id)
-    print(got.__dict__)
+    pretty_print(got)
     print("devices:")
-    for device in got.devices:
-        print(device.__dict__)
+    pretty_print(got.devices)
     print()
 
 
 def run_list() -> None:
     email, token = get_credentials()
     client = KentikAPI(email, token)
+
+    print("GET ALL")
     labels = client.device_labels.get_all()
-    for l in labels:
-        print(l.__dict__)
+    pretty_print(labels)
+    print()
 
 
 if __name__ == "__main__":
     # run_get_with_devices()
     run_crud()
-    # run_list()
+    run_list()
