@@ -1,5 +1,5 @@
-from kentik_api.api_calls.api_call_decorators import get, post, put, delete, payload_type
 from kentik_api.api_calls.api_call import APICall, ResourceID
+from kentik_api.api_calls.api_call_decorators import delete, get, payload_type, post, put
 
 
 @get
